summaryrefslogtreecommitdiff
path: root/gst/mpegtsdemux/mpegtspacketizer.c
diff options
context:
space:
mode:
authorEdward Hervey <bilboed@bilboed.com>2014-06-25 14:50:05 +0200
committerEdward Hervey <bilboed@bilboed.com>2014-06-25 14:50:05 +0200
commit22dfd9aef361c6e630fe32d6b7f6c07588a2dff9 (patch)
tree48cbfc0212922b7d8c6a98f1d7854a9326358788 /gst/mpegtsdemux/mpegtspacketizer.c
parentcddabd751c760454915bcd3a485f241939499292 (diff)
downloadgstreamer-plugins-bad-22dfd9aef361c6e630fe32d6b7f6c07588a2dff9.tar.gz
mpegts: Unify API : GstMpegts / gst_mpegts_ / GST_*_MPEGTS_
It was previously a mix and match of both variants, introducing just too much confusion. The prefix are from now on: * GstMpegts for structures and type names (and not GstMpegTs) * gst_mpegts_ for functions (and not gst_mpeg_ts_) * GST_MPEGTS_ for enums/flags (and not GST_MPEG_TS_) * GST_TYPE_MPEGTS_ for types (and not GST_TYPE_MPEG_TS_) The rationale for chosing that is: * the namespace is shorter/direct (it's mpegts, not mpeg_ts nor mpeg-ts) * the namespace is one word under Gst * it's shorter (yah)
Diffstat (limited to 'gst/mpegtsdemux/mpegtspacketizer.c')
-rw-r--r--gst/mpegtsdemux/mpegtspacketizer.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/gst/mpegtsdemux/mpegtspacketizer.c b/gst/mpegtsdemux/mpegtspacketizer.c
index b504739df..fea8fc03a 100644
--- a/gst/mpegtsdemux/mpegtspacketizer.c
+++ b/gst/mpegtsdemux/mpegtspacketizer.c
@@ -469,12 +469,12 @@ mpegts_packetizer_parse_packet (MpegTSPacketizer2 * packetizer,
return PACKET_OK;
}
-static GstMpegTsSection *
+static GstMpegtsSection *
mpegts_packetizer_parse_section_header (MpegTSPacketizer2 * packetizer,
MpegTSPacketizerStream * stream)
{
MpegTSPacketizerStreamSubtable *subtable;
- GstMpegTsSection *res;
+ GstMpegtsSection *res;
subtable =
find_subtable (stream->subtables, stream->table_id,
@@ -874,7 +874,7 @@ mpegts_packetizer_has_packets (MpegTSPacketizer2 * packetizer)
* * The section applies now (current_next_indicator)
* * The section is an update or was never seen
*
* The section should be a new GstMpegTsSection:
* * properly initialized
* * With pid, table_id AND section_type set (move logic from mpegtsbase)
* * With data copied into it (yes, minor overhead)
@@ -884,12 +884,12 @@ mpegts_packetizer_has_packets (MpegTSPacketizer2 * packetizer)
* If more than one section is available, the 'remaining' field will
* be set to the beginning of a valid GList containing other sections.
* */
-GstMpegTsSection *
+GstMpegtsSection *
mpegts_packetizer_push_section (MpegTSPacketizer2 * packetizer,
MpegTSPacketizerPacket * packet, GList ** remaining)
{
- GstMpegTsSection *section;
- GstMpegTsSection *res = NULL;
+ GstMpegtsSection *section;
+ GstMpegtsSection *res = NULL;
MpegTSPacketizerStream *stream;
gboolean long_packet;
guint8 pointer = 0, table_id;
@@ -874,7 +874,7 @@ mpegts_packetizer_has_packets (MpegTSPacketizer2 * packetizer)
* * The section is an update or was never seen
*
- * The section should be a new GstMpegTsSection:
+ * The section should be a new GstMpegtsSection:
* * properly initialized
* * With pid, table_id AND section_type set (move logic from mpegtsbase)